@@ -1,3 +1,4 @@
+# mypy: allow-untyped-defs
 import contextlib
 import multiprocessing
 import os
@@ -16,7 +17,7 @@ import pytest
 def ignore_encoding_warning():
     with warnings.catch_warnings():
         with contextlib.suppress(NameError):  # new in 3.10
-            warnings.simplefilter("ignore", EncodingWarning)  # type: ignore [name-defined]  # noqa: F821
+            warnings.simplefilter("ignore", EncodingWarning)  # type: ignore [name-defined]
         yield
 
 
@@ -1240,9 +1241,9 @@ class TestWINLocalPath:
 
     def test_owner_group_not_implemented(self, path1):
         with pytest.raises(NotImplementedError):
-            path1.stat().owner
+            _ = path1.stat().owner
         with pytest.raises(NotImplementedError):
-            path1.stat().group
+            _ = path1.stat().group
 
     def test_chmod_simple_int(self, path1):
         mode = path1.stat().mode
