@@ -1,3 +1,4 @@
+# mypy: allow-untyped-defs
 import inspect
 from pathlib import Path
 import sys
@@ -116,12 +117,12 @@ class TestDoctests:
     def test_importmode(self, pytester: Pytester):
         pytester.makepyfile(
             **{
-                "namespacepkg/innerpkg/__init__.py": "",
-                "namespacepkg/innerpkg/a.py": """
+                "src/namespacepkg/innerpkg/__init__.py": "",
+                "src/namespacepkg/innerpkg/a.py": """
                   def some_func():
                     return 42
                 """,
-                "namespacepkg/innerpkg/b.py": """
+                "src/namespacepkg/innerpkg/b.py": """
                   from namespacepkg.innerpkg.a import some_func
                   def my_func():
                     '''
@@ -132,6 +133,10 @@ class TestDoctests:
                 """,
             }
         )
+        # For 'namespacepkg' to be considered a namespace package, its containing directory
+        # needs to be reachable from sys.path:
+        # https://packaging.python.org/en/latest/guides/packaging-namespace-packages
+        pytester.syspathinsert(pytester.path / "src")
         reprec = pytester.inline_run("--doctest-modules", "--import-mode=importlib")
         reprec.assertoutcome(passed=1)
 
@@ -189,7 +194,7 @@ class TestDoctests:
         )
         doctest = f"""
             >>> "{test_string}"
-            {repr(test_string)}
+            {test_string!r}
         """
         fn = pytester.path / "test_encoding.txt"
         fn.write_text(doctest, encoding=encoding)
@@ -728,7 +733,7 @@ class TestDoctests:
                 >>> name = 'с' # not letter 'c' but instead Cyrillic 's'.
                 'anything'
                 """
-            '''
+            '''  # noqa: RUF001
         )
         result = pytester.runpytest("--doctest-modules")
         result.stdout.fnmatch_lines(["Got nothing", "* 1 failed in*"])
@@ -877,6 +882,25 @@ class TestDoctests:
         result = pytester.runpytest(p, "--doctest-modules")
         result.stdout.fnmatch_lines(["*collected 1 item*"])
 
+    def test_setup_module(self, pytester: Pytester) -> None:
+        """Regression test for #12011 - setup_module not executed when running
+        with `--doctest-modules`."""
+        pytester.makepyfile(
+            """
+            CONSTANT = 0
+
+            def setup_module():
+                global CONSTANT
+                CONSTANT = 1
+
+            def test():
+                assert CONSTANT == 1
+            """
+        )
+        result = pytester.runpytest("--doctest-modules")
+        assert result.ret == 0
+        result.assert_outcomes(passed=1)
+
 
 class TestLiterals:
     @pytest.mark.parametrize("config_mode", ["ini", "comment"])
