@@ -1,3 +1,4 @@
+# mypy: allow-untyped-defs
 import sys
 import textwrap
 
@@ -73,7 +74,7 @@ class TestEvaluation:
             """@pytest.mark.skipif("not hasattr(os, 'murks')")""",
             """@pytest.mark.skipif(condition="hasattr(os, 'murks')")""",
         ]
-        for i in range(0, 2):
+        for i in range(2):
             item = pytester.getitem(
                 f"""
                 import pytest
@@ -1491,54 +1492,6 @@ def test_fail_using_reason_works_ok(pytester: Pytester) -> None:
     result.assert_outcomes(failed=1)
 
 
-def test_fail_fails_with_msg_and_reason(pytester: Pytester) -> None:
-    p = pytester.makepyfile(
-        """
-        import pytest
-
-        def test_fail_both_arguments():
-            pytest.fail(reason="foo", msg="bar")
-        """
-    )
-    result = pytester.runpytest(p)
-    result.stdout.fnmatch_lines(
-        "*UsageError: Passing both ``reason`` and ``msg`` to pytest.fail(...) is not permitted.*"
-    )
-    result.assert_outcomes(failed=1)
-
-
-def test_skip_fails_with_msg_and_reason(pytester: Pytester) -> None:
-    p = pytester.makepyfile(
-        """
-        import pytest
-
-        def test_skip_both_arguments():
-            pytest.skip(reason="foo", msg="bar")
-        """
-    )
-    result = pytester.runpytest(p)
-    result.stdout.fnmatch_lines(
-        "*UsageError: Passing both ``reason`` and ``msg`` to pytest.skip(...) is not permitted.*"
-    )
-    result.assert_outcomes(failed=1)
-
-
-def test_exit_with_msg_and_reason_fails(pytester: Pytester) -> None:
-    p = pytester.makepyfile(
-        """
-        import pytest
-
-        def test_exit_both_arguments():
-            pytest.exit(reason="foo", msg="bar")
-        """
-    )
-    result = pytester.runpytest(p)
-    result.stdout.fnmatch_lines(
-        "*UsageError: cannot pass reason and msg to exit(), `msg` is deprecated, use `reason`.*"
-    )
-    result.assert_outcomes(failed=1)
-
-
 def test_exit_with_reason_works_ok(pytester: Pytester) -> None:
     p = pytester.makepyfile(
         """
